.. image:: GUNC_LOGO.svg
    :width: 400px
    :align: left
    :alt: GUNC

|
|
|
|
|
|
|

.. image:: https://img.shields.io/pypi/v/gunc.svg
        :target: https://pypi.python.org/pypi/gunc
.. image:: https://anaconda.org/bioconda/gunc/badges/version.svg
        :target: https://anaconda.org/bioconda/gunc
.. image:: https://anaconda.org/bioconda/gunc/badges/downloads.svg
        :target: https://anaconda.org/bioconda/gunc
.. image:: https://img.shields.io/badge/license-GPLv3-blue.svg?style=flat-square&maxAge=2678400
        :target: https://choosealicense.com/licenses/gpl-3.0/
.. image:: https://anaconda.org/bioconda/gunc/badges/installer/conda.svg
        :target: https://conda.anaconda.org/bioconda



Python package for detection of chimerism and contamination in prokaryotic genomes.

* Free software: GNU General Public License v3 or later
* Documentation: `GUNC Documentation <https://grp-bork.embl-community.io/gunc/>`_
